@@ -8,6 +8,7 @@ from typing import Optional
 from typing import Sequence
 from typing import Tuple
 
+import pandas as pd
 from alvin_api_client.model.impact_analysis_platform_request import (
     ImpactAnalysisPlatformRequest,
 )
@@ -15,10 +16,7 @@ from alvin_api_client.model.impact_analysis_query_request import (
     ImpactAnalysisQueryRequest,
 )
 from alvin_api_client.model.impact_analysis_request import ImpactAnalysisRequest
-from alvin_api_client.model.impact_analysis_sidebar_data_node import (
-    ImpactAnalysisSidebarDataNode,
-)
-from alvin_api_client.model.impact_analysis_v2_response import ImpactAnalysisV2Response
+from alvin_api_client.model.impact_analysis_response import ImpactAnalysisResponse
 from rich.console import Console
 from sqlfluff.core import FluffConfig
 from sqlfluff_templater_dbt.templater import DbtTemplater
@@ -29,9 +27,9 @@ from alvin_cli.schemas.models import FileGitHistory
 from alvin_cli.schemas.models import GitChangeType
 from alvin_cli.schemas.models import ImpactAnalysisCLIReport
 from alvin_cli.schemas.models import Model
-from alvin_cli.utils import default_api
+from alvin_cli.utils.api_client import default_api
 from alvin_cli.utils.dbt_compile import main as dbt_compile
-from alvin_cli.utils.git_metadata import get_git_history
+from alvin_cli.utils.helper_functions import print_node_stats_impact_analysis
 from alvin_cli.utils.utils_dbt import get_json
 from alvin_cli.utils.utils_dbt import get_model_sqls
 from alvin_cli.utils.utils_dbt import get_models
@@ -41,7 +39,9 @@ console = Console()
 wide_console = Console(width=350)
 
 
-def check_sql_impact_analysis(paths: Sequence[str], manifest: Dict[str, Any]) -> int:
+def check_sql_impact_analysis(
+    paths: Sequence[str], manifest: Dict[str, Any], platform_id: str
+) -> int:
     report = ImpactAnalysisCLIReport(
         markdown_text=f"[![ALVIN](https://alvin-public-assets.s3.eu-central-1.amazonaws.com/"
         f"black-color-icon-xsmall.svg)"
@@ -80,7 +80,9 @@ def check_sql_impact_analysis(paths: Sequence[str], manifest: Dict[str, Any]) ->
     for model in models:
         # We run all, but we need to store if
         # any model execution failed
-        status_code = __process_model(model, status_code, report)
+        status_code = __process_model(
+            model, status_code, report, platform_id=platform_id
+        )
         if status_code:
             all_status_code = status_code
 
@@ -92,159 +94,6 @@ def check_sql_impact_analysis(paths: Sequence[str], manifest: Dict[str, Any]) ->
     return all_status_code
 
 
-def __process_model(
-    model: Model, status_code: int, report: ImpactAnalysisCLIReport
-) -> int:
-    node = model.node
-    if node:
-        file_git_history: Optional[FileGitHistory] = get_git_history(node)
-
-        original_file_path = node["original_file_path"]
-        relation_name = node.get("relation_name")
-
-        # If we don't have the relation name, calculate on the fly
-        if relation_name is None:
-            relation_name = f"{node['database']}.{node['schema']}.{node['name']}"
-
-        dbt_create_as_str = __resolve_dbt_query(
-            original_file_path, relation_name, node["config"]
-        )
-
-        response = __call_impact_analysis_api(dbt_create_as_str, node, file_git_history)
-
-        console.print(f"Changed Entity: [underline]{relation_name}", style="bold")
-
-        query_report = response.query_report
-
-        report.markdown_text = report.markdown_text + f"\n## {relation_name}"
-
-        if query_report:
-            query_report_url_code = query_report.query_report_url_code
-            report_url = __create_report_url(query_report_url_code)
-            wide_console.print(f"└──FULL REPORT: {report_url}", overflow="ellipsis")
-            report.markdown_text = (
-                report.markdown_text
-                + f"\n[![RUN](https://alvin-public-assets.s3.eu-central-1.amazonaws.com/run.svg)]"
-                f"({report_url})\n"
-            )
-        else:
-            report.markdown_text = report.markdown_text + "\n\n"
-
-        hierarchy: Dict[str, ImpactAnalysisSidebarDataNode] = response.hierarchy
-
-        total_changed_columns = 0
-        total_impacted_entities = 0
-        if hierarchy:
-            for entity_id, value in hierarchy.items():
-                # Here we map the amount of columns deleted for each entity, right now
-                # we only iterate on this once, since it processes only 1 table, on DBT
-                # we do impact analysis only on table level, so parent here is always Tables.
-                total_changed_children = (
-                    len(value.children.keys()) if value.children else 0
-                )
-                total_changed_columns = total_changed_columns + total_changed_children
-                total_impacted_entities = total_impacted_entities + value.num_entities
-
-        rows = [
-            ["Columns Deleted", total_changed_columns],
-            ["Impacted Entities", total_impacted_entities],
-        ]
-
-        report.markdown_text = (
-            report.markdown_text
-            + f"\n {tabulate(rows, headers=['Metric', 'Total'], tablefmt='github')}"
-        )
-
-        console.print("Impact Summary")
-        console.print("----------------------------")
-        console.print(
-            f"[{'yellow' if total_changed_columns > 0 else 'default'}] "
-            f"Columns Deleted: {total_changed_columns}"
-        )
-        console.print(
-            f"[{'yellow' if total_impacted_entities > 0 else 'default'}] "
-            f"Impacted Entities: {total_impacted_entities}"
-        )
-        console.print("----------------------------")
-
-        entity_mapping: Dict[str, List[str]] = response.entity_mapping
-        entities: Dict[str, Dict[str, Any]] = response.entities
-
-        console.print("")
-
-        if entity_mapping:
-            for entity_id, affected_entities_id in entity_mapping.items():
-                entity_impact_data: Dict[str, Any] = entities.get(entity_id, {})
-                entity_id_data = entity_impact_data.get("entityId", {})
-                platform_id = entity_id_data.get("platformId")
-                entity_type = entity_id_data.get("entityType")
-                entity_id = entity_id_data.get("entityId")
-                entity_url = __create_entity_url(entity_id, platform_id, entity_type)
-
-                usage_data = entity_impact_data.get("usageStats", {})
-                usage_count = usage_data.get("usageCount", 0)
-
-                wide_console.print(
-                    f"[{'red' if usage_count > 0 else 'yellow'} bold]DIRECT Impact"
-                    f"[default bold] -> {entity_type} - {entity_id} - {usage_count} usage in last 30 days",
-                    overflow="ellipsis",
-                )
-
-                formatted_impact_status = (
-                    "![DIRECT]("
-                    "https://alvin-public-assets.s3.eu-central-1.amazonaws.com/direct.svg)"
-                )
-
-                wide_console.print(f"└──URL: {entity_url}", overflow="ellipsis")
-
-                rows = []
-
-                report.markdown_text = (
-                    report.markdown_text
-                    + f"\n\n**{entity_type}** {entity_id} **DELETED**\n"
-                )
-
-                report.markdown_text = (
-                    report.markdown_text
-                    + "\n<details>\n<summary>Impact Report</summary>\n"
-                )
-
-                last_used_date = usage_data.get("lastUsedDate")
-                rows.append(
-                    [
-                        0,
-                        formatted_impact_status,
-                        f"[{platform_id} - {entity_id}]({entity_url})",
-                        entity_type,
-                        num_of_days_from_now(last_used_date),
-                        usage_count,
-                    ]
-                )
-
-                entities_rows, status_code_sub = process_affected_entities(
-                    affected_entities_id,
-                    entities,
-                )
-
-                rows.extend(entities_rows)
-
-                if status_code_sub == 1:
-                    status_code = status_code_sub
-
-                report.markdown_text = (
-                    report.markdown_text
-                    + f"\n\n{tabulate(rows, headers=['Depth', 'Impact', 'Name', 'Type', 'Last Used', '30 Day Usage'], tablefmt='github')}"
-                )
-                report.markdown_text = report.markdown_text + "\n</details>\n"
-
-                console.print("")
-
-    else:
-        status_code = 1
-        print(f"Invalid model `{model.model_id}` in manifest file. ")
-    return status_code
-
-
 def process_affected_entities(
     affected_entities_id: List[str],
     entities: Dict[str, Dict[str, Any]],
@@ -372,8 +221,8 @@ def __create_entity_url(
 def __resolve_dbt_query(
     original_file_path: str, relation_name: str, node_config: Dict[str, Any]
 ) -> str:
-    dbt_templater = DbtTemplater()
-    fluff_config = FluffConfig.from_root()
+    dbt_templater = DbtTemplater(profiles_dir=settings.dbt_profiles_dir)
+    fluff_config = FluffConfig.from_kwargs(dialect=settings.dialect)
     template_result, _ = dbt_templater.process(
         fname=original_file_path, config=fluff_config
     )
@@ -406,14 +255,13 @@ def __call_impact_analysis_api(
     dbt_create_as_str: str,
     node: Dict[str, Any],
     file_git_history: Optional[FileGitHistory],
-) -> ImpactAnalysisV2Response:
+    platform_id: str,
+) -> ImpactAnalysisResponse:
 
     impact_analysis_query_request = ImpactAnalysisQueryRequest(
         source_text=dbt_create_as_str
     )
-    impact_analysis_platform_request = ImpactAnalysisPlatformRequest(
-        id=settings.alvin_platform_id
-    )
+    impact_analysis_platform_request = ImpactAnalysisPlatformRequest(id=platform_id)
     impact_analysis_request = ImpactAnalysisRequest(
         query=impact_analysis_query_request, platform=impact_analysis_platform_request
     )
@@ -432,15 +280,86 @@ def __call_impact_analysis_api(
                 )
                 impact_analysis_query_request.renamed_entity_id = renamed_entity_id
 
-    response: ImpactAnalysisV2Response = (
-        default_api.get_impact_by_query_api_v2_impact_analysis_query_post(
-            impact_analysis_request
-        )
+    response: ImpactAnalysisResponse = default_api.run_impact_node_query_api_v2_impact_analysis_query_string_nodes_post(
+        impact_analysis_request
     )
     return response
 
 
-def run_check_sql_impact_analysis(file_names: List, manifest_file: str) -> None:
+def __process_model(
+    model: Model, status_code: int, report: ImpactAnalysisCLIReport, platform_id: str
+) -> int:
+    node = model.node
+
+    if node:
+        # file_git_history: Optional[FileGitHistory] = get_git_history(node)
+
+        original_file_path = node["original_file_path"]
+        relation_name = node.get("relation_name")
+
+        # If we don't have the relation name, calculate on the fly
+        if relation_name is None:
+            relation_name = f"{node['database']}.{node['schema']}.{node['name']}"
+
+        dbt_create_as_str = __resolve_dbt_query(
+            original_file_path, relation_name, node["config"]
+        )
+
+        response = __call_impact_analysis_api(
+            dbt_create_as_str, node, None, platform_id=platform_id
+        )
+
+        console.print(f"Changed Entity: [underline]{relation_name}", style="bold")
+
+        impact_analysis_response = response.impact_analysis_response
+        query_report = impact_analysis_response.query_report
+
+        report.markdown_text = report.markdown_text + f"\n## {relation_name}"
+
+        if query_report:
+            query_report_url_code = query_report.query_report_url_code
+            report_url = __create_report_url(query_report_url_code)
+            wide_console.print(f"└──FULL REPORT: {report_url}", overflow="ellipsis")
+            report.markdown_text = (
+                report.markdown_text
+                + f"\n[![RUN](https://alvin-public-assets.s3.eu-central-1.amazonaws.com/run.svg)]"
+                f"({report_url})\n"
+            )
+        else:
+            report.markdown_text = report.markdown_text + "\n\n"
+
+        console.print("\n\n")
+
+        report_stats = print_node_stats_impact_analysis(response)
+
+        report.markdown_text = (
+            report.markdown_text
+            + f"\n <b>{report_stats.total_impacted_assets}</b> assets and <b>{report_stats.total_impacted_users}</b> people impacted \n\n\n"
+        )
+
+        rows = []
+
+        for platform, impact in report_stats.impact_per_platform.items():
+            impact_stats = ""
+            for impact_status, count in impact.items():
+                impact_stats += f"{count}:{impact_status.title()}  "
+            rows.append({"Platform ID": platform, "Impact Status ": impact_stats})
+        df = pd.DataFrame(rows)
+
+        report.markdown_text = (
+            report.markdown_text
+            + f"\n {tabulate(df, headers= 'keys', tablefmt='github', showindex=False)}"
+        )
+
+    else:
+        status_code = 1
+        print(f"Invalid model `{model.model_id}` in manifest file. ")
+    return status_code
+
+
+def run_check_sql_impact_analysis(
+    file_names: List, manifest_file: str, platform_id: str
+) -> None:
     root_dir = os.getcwd()
     if settings.debug:
         print(root_dir)
@@ -460,4 +379,8 @@ def run_check_sql_impact_analysis(file_names: List, manifest_file: str) -> None:
         exit(1)
 
     if manifest:
-        exit(check_sql_impact_analysis(paths=file_names, manifest=manifest))
+        exit(
+            check_sql_impact_analysis(
+                paths=file_names, manifest=manifest, platform_id=platform_id
+            )
+        )
